/*****************************************************************/
/* FILE:        	w2assets.sas                             */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 2 assets and income            */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w2assets;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;

%include "~/ribeiro/datagen/header.inc";
options ps=2000 ls=150;
   
%macro h;

 
x zcat "&rawc2/a95pr_r.ssd01.Z" > "&local/a95pr_r.ssd01";
x zcat "&rawc2/a95j_h.ssd01.Z"  > "&local/a95j_h.ssd01";
x zcat "&rawc2/a95f_h.ssd01.Z"  > "&local/a95f_h.ssd01";
x zcat "&rawc2/a95cs_r.ssd01.Z"  > "&local/a95cs_r.ssd01";
x zcat "&rawc2/a95a_r.ssd01.Z"  > "&local/a95a_r.ssd01";
       
/*
proc contents data=local.a95pr_r;
proc contents data=local.a95cs_r;
proc contents data=local.a95a_r;
proc contents data=local.a95j_h;
proc contents data=local.a95f_h;
*/


/****************************/
/* Preload Variables        */  
/****************************/

data a95pr_r;
     set local.a95pr_r;
     hhidpn=hhid*1000+pn;

  /* Unfolding bracket randomization */
       
         keep D169; *    W1 REALESTATE V1721;
         keep D170; *    W1 TRANSPORT V1725;
         keep D171; *    W1 BUSINESS V1730;
         keep D172; *    W1 IRA V1735;
         keep D173; *    W1 STOCKS V1744;
         keep D174; *    W1 CHECKINGS/SAVINGS V1750;
         keep D175; *    W1 CD  V1756;
         keep D176; *    W1 BONDS V1762;
         keep D179; *    W1 OWN RENT;
         keep D181; *    W1 OWN MORT V1112;
         keep D182; *    W1 IWN #OF IW IN HH;
         keep D184; *    LIVE ON FARM;
              
         keep hhidpn ;
run;


/****************************/
/* Cover Screen Variables   */  
/****************************/

data a95cs_r;
     set local.a95cs_r;
     hhidpn=hhid*1000+pn;
     _DSUBHH=DSUBHH+0;  
     _HHID=HHID+0;    
     _PN=PN+0;      
     drop DSUBHH HHID PN;
run;

data a95cs_r;
     set a95cs_r;
     rename
     _DSUBHH=DSUBHH  
     _HHID=HHID   
     _PN=PN;   
     run;


data a95cs_r;
    set a95cs_r;
    keep hhidpn hhid dsubhh pn;
    
    keep D376; *   R FAM/NON V105;
    keep D377; *   R FIN/NON V106;
    famr2=d376;
    finr2=d377;
    
    keep D240; *    CS11.R-WHERE LIVE;
    keep D218; *    CS1A.PROXY/SELF INTERVIEW;
    keep D417; *    CS25.MONTH MOVED TO NURS HOME;
    keep D418; *    CS25.YEAR MOVED TO NURS HOME;
    keep D420; *    CS26.NURHM: STILL OWN/RENT HOME;
    keep D435; *    CS35A. ASSIGN 1 OR 2 RESIDENCE;
    keep D441; *    CS36C.R MOVED MAIN RESIDENCE;

    keep famr2 finr2 dfamr dfinr;
    run;

    proc freq; 
        tables 
            finr2*dfinr famr2*dfamr  / list missing; 


 /****************************/
 /* Section J Variables      */  
 /****************************/
     
    data a95j_h;
        set local.a95j_h;
        _DSUBHH=DSUBHH+0;  
        _HHID=HHID+0;    
        _DPN_FAM=DPN_FAM+0;
        _DPN_FIN=DPN_FIN+0;
        drop DSUBHH HHID DPN_FAM DPN_FIN;
    run;
    
    data a95j_h;
        set a95j_h;
        rename
            _DSUBHH=DSUBHH  
            _HHID=HHID
            _DPN_FAM=DPN_FAM
            _DPN_FIN=DPN_FIN;
        drop bsubhh;
    run;
    


/****************************/
/* Section F Variables      */  
/****************************/

data a95f_h;
    set local.a95f_h;
    _DSUBHH=DSUBHH+0;  
    _HHID=HHID+0;    
    drop DSUBHH HHID DPN_FAM DPN_FIN;
run;

data a95f_h;
    set a95f_h;
    rename
        _DSUBHH=DSUBHH  
        _HHID=HHID;   
    drop bsubhh;
run;

%merge(w2assets,a95cs_r,a95pr_r,hhidpn);
%merge(w2assets,w2assets,a95j_h,hhid dsubhh);
%merge(w2assets,w2assets,a95f_h,hhid dsubhh);

data w2assets;
    set w2assets;
    if dfinr in(1,2,3,4) then finr20=1;
    else finr20=5;
    rename finr2=finr2b;
    rename finr20=finr2;
    run;
    
data local8.w2ast0;
    set w2assets;
    run;

x /bin/rm "&local/a95pr_r.ssd01";
x /bin/rm "&local/a95j_h.ssd01";
x /bin/rm "&local/a95f_h.ssd01";
x /bin/rm "&local/a95cs_r.ssd01";
x /bin/rm "&local/a95a_r.ssd01";
    
/* do tests on finr indicator */
    
proc freq;
    tables
        dpn_fin dpn_fam pn
        finr2*finr2b*dfinr
        /missing list;


proc sort; by hhid dsubhh dfinr;
data tmp;
set w2assets;
 by hhid dsubhh;
 if first.dsubhh;
 run;
 

proc freq;
    tables
        dpn_fin dpn_fam pn
        finr2*finr2b*dfinr
        /missing list;

data tmpj;
    set a95j_h;
    keep hhid dpn_fin;
    rename dpn_fin=pn;
run;

%merge(tmp,w2assets,tmpj,hhid pn);
data tmp;
    set tmp;
    inhh=in2;
    run;

proc freq;
    tables
        inhh*finr2*finr2b*dfinr
        /missing list;
run;

%mend;
*%h;

data w2assets;
    set local8.w2ast0;    
run;
       
%count(w2assets,hhid dsubhh,nhhid);

proc sort data=w2assets; by hhid dsubhh finr2;
data test1 test2;
    set w2assets;
    by hhid dsubhh finr2;
    if first.dsubhh then output test1;
    else output test2;
    run;

proc freq data=test1;
    tables
        nhhid*finr2 /list missing;
proc freq data=test2;
    tables
        nhhid*finr2 /list missing;

    
/* Subset to HH level */    
            
proc sort data=w2assets; by hhid dsubhh finr2;
data w2assets;
    set w2assets;
    by hhid dsubhh finr2;
    if first.dsubhh;
    drop hhidpn;
run;
    

%include cbrak2; *macro for coding all assets;

     %vtic(w2assets);
     
   /* construct lead indicators for rlst bsns */

   /* 
    * There are missing values in the lead variables
    * these are treated as if the value was 8 or 9
    */

       
data w2assets;
    set w2assets;
    lrlst=d3964;    
    if lrlst in(1,2) then lrlst=1; 
    lbsns=d4005;    
    if lbsns in(1,2) then lbsns=1; 
run;


proc freq;
    tables finr2*d169*lrlst*d3969*d3970*d3971*d3972*d3973*d3974*d3975*d3976*d3977 /list missing;
run;

*%macro cbrak2(type,lead,amt,prev,listca,listbp,excl);

%cbrak2(rlst,lrlst,d3965,d169,d3969 d3970 d3971 d3972 d3973 d3974 d3975 d3976 d3977,5000 20000 50000 200000 500000 1000000 2000000,9999990);

proc freq;
    tables finr2*d171*lrlst*d4010*d4011*d4012*d4013*d4014*d4015*d4016*d4017*d4018 /list missing;
run;

%cbrak2(bsns,lbsns,d4006,d171,d4010 d4011 d4012 d4013 d4014 d4015 d4016 d4017 d4018,5000 20000 50000 200000 500000 1000000 2000000,9999990);


/****************************************/
/* construct lead indicators for IRA 1-3*/
/****************************************/
proc freq;
    tables finr2*d4045*d4046/list missing;
    run;

data w2assets;
    set w2assets;
        if d4045=1 then do;
            if d4046=1 then do;
                lira1=1;
                lira2=5;
                lira3=5;
                end;
            if d4046=2 then do;
                lira1=1;
                lira2=1;
                lira3=5;
                end;
            if d4046 in(3,4) then do;
                lira1=1;
                lira2=1;
                lira3=1;
                end;
            if d4046 in(7,8,9) then do;
                lira1=1;
                lira2=5;
                lira3=5;
                end;
            end;

        if d4045 in(2,5) then do;
            lira1=5;
            lira2=5;
            lira3=5;
            end;

        if d4045 in(.,8,9) then do;
            lira1=8;
            lira2=5;
            lira3=5;
            end;
run;

%cbrak2(ira1,lira1,d4048,d172,d4052 d4053 na    d4055 d4056 d4057 na    d4059 d4060,5000 20000 50000 200000 1000000,9999990);

/*
ERROR in 3 obs - set d4098 to missing

HHID     D4090  D172  D4093  D4094  D4096  D4097  D4098  D4100  D4101
200787  9999998   3      5      5      5      8      1      .      .
200808  9999998   3      5      5      5      8      1      .      .
203017  9999999   3      5      5      5      8      1      .      .
*/

    
data w2assets;
    set w2assets;
    if hhid in(200787,200808,203017) then d4098=.;
run;
    
%cbrak2(ira2,lira2,d4090,d172,d4093 d4094 na    d4096 d4097 d4098 na    d4100 d4101,5000 20000 50000 200000 1000000,9999990);
%cbrak2(ira3,lira3,d4129,d172,d4132 d4133 na    d4135 d4136 d4137 na    d4139 d4140,5000 20000 50000 200000 1000000,9999990);


/****************************************/
/* construct unified IRA variable       */
/****************************************/

proc freq;
tables 
d_ira12*d_ira22*d_ira32
diira12*diira22*diira32
c_ira12*c_ira22*c_ira32
d_ira12*d_ira22*d_ira32*i_ira12*i_ira22*i_ira32
/ list missing;

proc sort; by d_ira12;
proc means;
by d_ira12;
var a_ira12;

proc sort; by d_ira22;
proc means;
   by d_ira22;
   var a_ira22;
proc sort; by d_ira32;
proc means;
by d_ira32;
var a_ira32;

%let bp0=0;
%let bp1=1;
%let bp2=5000;
%let bp3=20000;
%let bp4=50000;
%let bp5=200000;
%let bp6=1000000;
%let bp7=10000000;

data w2assets;
    set w2assets;
    
    array a_s{3} a_ira12 a_ira22 a_ira32;
    array c_s{3} c_ira12 c_ira22 c_ira32;
    array lows{23}  _temporary_ (
        &bp0 &bp1 &bp2 &bp3 &bp4 &bp5 &bp6
        &bp1 &bp1 &bp1 &bp1
        &bp2 &bp2 &bp2 &bp2
        &bp3 &bp3 &bp3
        &bp4 &bp4
        &bp5
        &bp1 &bp0);
    array highs{23} _temporary_ (
        &bp0 &bp2 &bp3 &bp4 &bp5 &bp6 &bp7
        &bp3 &bp4 &bp5 &bp6
        &bp4 &bp5 &bp6 &bp7
        &bp5 &bp6 &bp7
        &bp6 &bp7
        &bp7
        &bp7 &bp7);

    if d_ira12 ne . then do;
        low=0;
        high=0;
        do i=1 to 3;
            if a_s{i} ne . then do;
                low=low+a_s{i};
                high=high+a_s{i};
                end;
            else do;
                do j=1 to 23;
                    low=low+(c_s{i}=j-1)*lows{j};
                    high=high+(c_s{i}=j-1)*highs{j};
                    end;
                end;
            end;
        if high=low then do;
            if high=0 then do;
                d_ira2=0;
                diira2=0;
                c_ira2=0;
                a_ira2=0;
                i_ira2=0;
                end;
            else do;
                d_ira2=1;
                diira2=0;
                a_ira2=high;
                c_ira2=
                    0*(a_ira2=&bp0)+
                    1*(&bp1 <= a_ira2 < &bp2) +
                    2*(&bp2 <= a_ira2 < &bp3) +
                    3*(&bp3 <= a_ira2 < &bp4) +
                    4*(&bp4 <= a_ira2 < &bp5) +
                    5*(&bp5 <= a_ira2 < &bp6) +
                    6*(&bp6 <= a_ira2       );
                i_ira2=0;
                end;
            end;
        else do;
            L0= (0=low);
            L1= (&bp1  <= low and low < &bp2);
            L2= (&bp2  <= low and low < &bp3);
            L3= (&bp3  <= low and low < &bp4);
            L4= (&bp4  <= low and low < &bp5);
            L5= (&bp5  <= low and low < &bp6);
            L6= (&bp6  <= low and low        );
            
            H1= (&bp1 <= high and high < &bp2);
            H2= (&bp2 <= high and high < &bp3);
            H3= (&bp3 <= high and high < &bp4);
            H4= (&bp4 <= high and high < &bp5);
            H5= (&bp5 <= high and high < &bp6);
            H6= (&bp6 <= high and high        );
            
            if      L1 and H1 then c_ira2=1;
            else if L2 and H2 then c_ira2=2;
            else if L3 and H3 then c_ira2=3;
            else if L4 and H4 then c_ira2=4;
            else if L5 and H5 then c_ira2=5;
            else if L6 and H6 then c_ira2=6;

            else if L1 and H2 then c_ira2=7;
            else if L1 and H3 then c_ira2=8;
            else if L1 and H4 then c_ira2=9;
            else if L1 and H5 then c_ira2=10;

            else if L2 and H3 then c_ira2=11;
            else if L2 and H4 then c_ira2=12;
            else if L2 and H5 then c_ira2=13;
            else if L2 and H6 then c_ira2=14;

            else if L3 and H4 then c_ira2=15;
            else if L3 and H5 then c_ira2=16;
            else if L3 and H6 then c_ira2=17;

            else if L4 and H5 then c_ira2=18;
            else if L4 and H6 then c_ira2=19;

            else if L5 and H6 then c_ira2=20;

            else if L1 and H6 then c_ira2=21;
            else if L0 and H5 then c_ira2=22;
            
            d_ira2=1;
            diira2=0;
            i_ira2=1;
            if c_ira2=22 then do;
                d_ira2=2; 
                diira2=1;
                end;
            end;
        end;
    else if d_ira12 eq . then do;
        d_ira2=2;
        diira2=1;
        i_ira2=1;
        c_ira2=22;
        end;
run;    


proc freq;
*    where finr2=1;
    tables d_ira2 diira2
      i_ira2 c_ira2
      d_ira2*c_ira2
      diira2*c_ira2
      i_ira2*c_ira2
        /   missing;
tables c_ira2*c_ira12*c_ira22*c_ira32  /list   missing;


proc print;
    where c_ira2=20;
    var d_ira12 d_ira22 d_ira32 c_ira12 c_ira22 c_ira32 low high L0-L6 H1-H6;
run;



%cbrak2(stck,d4338,d4339,d173,d4343 d4344 na    d4346 d4347 d4348 na    d4350 d4351,2000 10000 100000 750000 1500000,99999990);
%cbrak2(bond,d4381,d4382,d176,d4386 d4387 na    d4389 d4390 d4391 na    d4393 d4394,2000 10000  50000 200000  500000,9999990);
%cbrak2(chck,d4424,d4425,d174,d4429 d4431 na    d4432 d4433 d4434 na    d4436 d4437,2000 20000  50000 100000  500000,9999990);
%cbrak2(cd  ,d4463,d4464,d175,d4468 d4469 na    d4471 d4472 d4473 na    d4475 d4476,2500 25000 125000 250000  500000,9999990);
%cbrak2(trns,d4499,d4500,d170,d4502 d4503 na    d4504 d4505 d4506 na    d4508 d4509,1000  5000  20000 100000  200000, 999990);
%cbrak2(othr,d4512,d4513,na  ,d4514 d4515 d4516                                    ,5000 50000 100000               ,9999990);
%cbrak2(debt,d4725,d4726,na  ,d4727 d4728 d4729                                    , 500  5000  50000               ,999990);


data w2assets;
    set w2assets;
    if d4642=0 then ltinc=0;
    if d4642>0 and d4642<9999997 then ltinc=1;
    if d4642>=9999997 or d4642=. then ltinc=2;
run;

proc freq data=w2assets;
    tables finr2*ltinc*d4644*d4645*d4646*d4647*d4648*d4649*d4650/list missing;
run;

proc print;
    where ltinc=1 and d4648=5;
    var finr2 ltinc d4642 d4644 d4645 d4646 d4647 d4648 d4649 d4650;
run;

data w2assets;
    set w2assets;
    if ltinc=1 and d4648=5 then do;
        d4648=.;
        d4650=.;
        end;             
    if ltinc=0 then do;
        ltinc=1;
        d4642=.;
        end;
    if ltinc=2 then ltinc=1;
    prev=3;       
run;

proc freq data=w2assets;
    tables ltinc*d4644*d4645*d4646*d4647*d4648*d4649*d4650/list missing;
run;

%cbrak2(tinc,ltinc,d4642,prev,d4650 d4644 d4646 d4645 d4647 d4648 d4649 prev prev,5000 10000 20000 30000 50000 75000 100000,9999990);
data w2assets;
    set w2assets;
    drop prev ltinc;
run;

proc freq;
    tables  d240 d420 d441 d184/ missing;
    tables d240*d420*d441*d184*d2224*d2225*d2226*d2229*d2231*d2232*d2234 /list missing;
run;

data w2assets;
    set w2assets;
    if d2246 ne . then do;
        housv=1;
        if d2246>99999990 then housv=0;
        end;
run;


data w2assets;
    set w2assets;
    if d240=1 then do; * Nursing home ;
        if d420=1 then do; *Still own/rent;
            if d2225 ne 1 then do; *not mob home;
                l_mob=0;
                l_hous=2;
                if d2226=1 then l_hous=1;
                if d2226 in(2,7) then l_hous=0;
                end;
            else if d2225=1 then do; *mob home;
                l_mob=2;
                l_hous=0;
                if d2234 in(1,2,3) then l_mob=1;
                if d2234 in(4,7) then l_mob=0;
                end;
            end;
        else if d420=5 then do; *Does not own/rent;
            l_mob=0;
            l_hous=0;
            end;
        else do; *Does not own/rent;
            l_mob=0;
            l_hous=2;
            end;
        end;
    else if d240=5 then do; *Not in nursing home ;
        if d2225 eq 1 then do; *mob home;
            l_mob=2;
            l_hous=0;
            if d2234 in(1,2,3) then l_mob=1;
            if d2234 in(4,7) then l_mob=0;
            end;
        else if d2225 in(2,3,4,10,11,12,13,97) then do; *hous/apt;
            l_mob=0;
            l_hous=2;
            if d2224=1 then do; *Live farm;
                if d2229 in(1,2) then l_hous=1;
                if d2229 in(3,7) then l_hous=0;
                end;
            else do;
                if d2226=1 then l_hous=1;
                if d2226 in(2,7) then l_hous=0;
                end;
            end;
        else do;
                * NOTE: DK/RF to type of house and/or RF/DK to own house;
                * will be treated as missing ownership and therefore imputed;
            l_mob=0;
            l_hous=2;
            end;
        end;

    if d2225 ne . then do;
        mobhome2=(d2225=1);
        singfam2=(d2225=2);
        duplex2=(d2225=3);
        aptment2=(d2225=4);
        othhous2=(d2225 in(10,11,12,13,97));
        end;
    
    mobsite2 = (mobhome2=1 and d2234 in(1,2));   
    ownbldg2=(d2227=1);   
    farmlnd2=(d2224=1);
    farm2=(d2229=1); 
run;


proc freq;
    tables l_mob*l_hous*housv*d2224*d2225*d2226*d2229*d2231*d2232*d2234 /list missing;
    tables l_mob*l_hous*housv*d2247*d2248*d2249*d2250                   /list missing;
    run;

%cbrak2(mobh,l_mob ,d2246,na  ,d2247 d2248 d2249 d2250              , 15000  50000  150000 500000 ,9999990); 
%cbrak2(hous,l_hous,d2246,na  ,d2247 d2248 d2249 d2250              , 15000  50000  150000 500000 ,9999990); 
   

proc freq;
    tables l_mob*l_hous*d2251m1*d2251m2 /list missing;
run;

data w2assets;
    set w2assets;
        l_mort=0; l_mort2=0; l_loan=0;
        if l_hous=1 or l_mob=1 then do;
            if d2251m1=1 or d2251m2=1  then l_mort=1;
            if d2251m1=2 or d2251m2=2  then l_mort2=1;
            if d2251m1=3 or d2251m2=3  then l_loan=1;
            if d2251m1 in(8,9) then l_mort=2;
            end;
    run;

proc freq;
    tables l_mob*l_hous*l_mort*l_mort2*l_loan*d2251m1*d2251m2 /list missing;
    tables l_mob*l_hous*l_mort*l_mort2*l_loan*d2251m1*d2251m2*d2257*d2258*d2259 /list missing;
    tables l_mob*l_hous*l_mort*l_mort2*l_loan*d2251m1*d2251m2*d2264*d2265*d2266 /list missing;
    tables l_mob*l_hous*l_mort*l_mort2*l_loan*d2251m1*d2251m2*d2271*d2272*d2273 /list missing;
run;


%cbrak2(mort,l_mort ,d2256,na  ,d2257 d2258 d2259              ,5000  20000  100000,9999990); 
%cbrak2(2mrt,l_mort2,d2263,na  ,d2264 d2265 d2266              ,5000  20000  100000,9999990); 
%cbrak2(loan,l_loan ,d2270,na  ,d2271 d2272 d2273              ,5000  20000  100000,9999990); 

   
data w2assets;
   set w2assets;
   format   
      c_rlst2 rlst2f.
      c_bsns2 bsns2f.
      c_ira12  ira2f.
      c_ira22  ira2f.
      c_ira32  ira2f.
      c_ira2   ira2f.
      c_stck2 stck2f.
      c_bond2 bond2f.
      c_cd2     cd2f.
      c_chck2 chck2f.
      c_trns2 trns2f.
      c_othr2 othr2f.
      c_debt2 debt2f.
      c_tinc2 tinc2f.

      c_hous2 hous2f.
      c_mobh2 mobh2f.
      c_mort2 mort2f.
      c_2mrt2 mort2f.
      c_loan2 mort2f.
     ;
   run;


data w2assets;
   set w2assets;
   
   numrom2=d2386;
   nhood2=d2395;
   if nhood2 not in(8,9,.) then do; 
       hoodex2=(d2395=1);
       hoodvg2=(d2395=2);
       hoodgd2=(d2395=3);
       hoodfr2=(d2395=4);
       hoodpr2=(d2395=5);
       end;
   
   hcond2=d2387;
   if hcond2 not in(8,9,.) then do; 
       condex2=(d2387=1);
       condvg2=(d2387=2);
       condgd2=(d2387=3);
       condfr2=(d2387=4);
       condpr2=(d2387=5);
       end;


*****************************************************************;
* Label variables ;
*****************************************************************;
   
   label
       
       ownbldg2='own entire bldg w2'
       singfam2='single family house w2'
       duplex2='duplex house w2'
       mobhome2='mobile home w2'
       mobsite2='mob home and site w2'
       othhous2='other house type w2'
       aptment2='apartment w2'
       
       numrom2='number of rooms w2'
       
       farm2='live on farm w2'
       farmlnd2='own farm/land w2'
       
       nhood2='neighborhood condition w2'
       hcond2='house condition w2'
       
       hoodex2='neighborhood exc w2'
       hoodvg2='neighborhood v good w2'
       hoodgd2='neighborhood good w2'
       hoodfr2='neighborhood fair w2'
       hoodpr2='neighborhood poor w2'

       condex2='house condition exc w2'
       condvg2='house condition v gd w2'
       condgd2='house condition good w2'
       condfr2='house condition fair w2'
       condpr2='house condition poor w2'
       ;

   %label(rlst,w2);
   %label(bsns,w2);
   %label(ira,w2);
   %label(ira1,w2);
   %label(ira2,w2);
   %label(ira3,w2);
   %label(stck,w2);
   %label(bond,w2);
   %label(chck,w2);
   %label(cd,w2);
   %label(othr,w2);
   %label(trns,w2);
   %label(debt,w2);
   %label(mobh,w2);
   %label(hous,w2);
   %label(mort,w2);
   %label(2mrt,w2);
   %label(loan,w2);
   %label(tinc,w2);

   drop AHIGH ALOW HIGH LOW I J LBSNS L0-L6 H0-H6
       LIRA1 LIRA2 LIRA3 LOW LRLST L_HOUS L_LOAN L_MOB L_MORT L_MORT2
       mobv housv;

run;

%vtoc(w2assets);


proc freq;
tables %list4(c_,2);;
tables c_tinc2;

proc means;
var %list4(d_,2);;
var %list4(di,2);;
var %list4(i_,2);;
var %list4(a_,2);;
var d_tinc2 ditinc2 i_tinc2 a_tinc2;

/*
proc freq;
    tables c_hous2*C_mobh2 /list missing;
endsas;
*/
    
data local8.w2assets;
   set w2assets;
   keep  hhid dsubhh dpn_fin;
   keep %include "&thisfile..vars";;
run;
   
proc means;
proc contents;

x '/usr/xpg4/bin/rm code_e';   
x '/usr/xpg4/bin/rm code_cat';   

   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst" ; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 
