/*****************************************************************/
/* FILE:        	cognition.sas                            */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code cognition variable                  */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

data allwv;
set allwv;

 born = 1923-birthyr;
 byr_2 = birthyr*birthyr;
 y1923_2 = 1923*1923;

 wm = white*male;
 mb = male*born;
 wb = white*born;
 wmb = white*male*born;
 born2 = y1923_2-byr_2;

 mb2 = male*born2;
 wb2 = white*born2;
 wmb2 = white*male*born2;

 age7074=(70*12<=agem1 & agem1<75*12);
run;

/*
proc reg ;
    where clean & eligible;
    model educ=born male white wm mb wb wmb
        born2 mb2 wb2 wmb2 / p
        selection=stepwise;
run;
*/
/*
              1   WHITE                1    0.1551   0.1551  240.2130  1191.1072   0.0001
              2   BORN                 2    0.0273   0.1825   24.5706   216.9210   0.0001
              3   MB                   3    0.0008   0.1832   20.5497     6.0055   0.0143
              4   WMB2                 4    0.0026   0.1858    2.2414    20.3170   0.0001
              5   WMB                  5    0.0003   0.1860    2.1630     2.0796   0.1493
*/

%let vs=born  white mb wmb wmb2 ;

proc reg outest=regcoef;
    where clean & eligible;
    model educ= &vs;
run;

proc print data=regcoef; 

data regcoef;
    set regcoef;
    intercep=0;
    white=0;
    _model_='adjeduc';
run;
proc print data=regcoef; 
proc score data=allwv score=regcoef out=allwv type=parms residual;
    var educ &vs;
run;    
    
/*
# ==========================================================
# SET STANDARDIZED COGNITIVE IMPAIRMENT (LAD ADJUSTMENT)
# ==========================================================
*/

data allwv;
    set allwv;
    drop 
        born byr_2 y1923_2
        wm mb  wb wmb
        born2 mb2 wb2 wmb2;

    lad0 = 14.2;
    lad1 = 0.2;
    lad2 = 0;
    lad3 = 3.2;

    label
        lad0='LAD intercept'
        lad1='LAD coeff on educ'
        lad2='LAD coeff on male: ==0'
        lad3='LAD coeff on white';
    
    cogstd = lad0 + lad1*adjeduc + lad2*male + lad3*white;
    
    label cogstd='standardized cogn score';
    
    gcog1 = cogimm1 - cogstd;
    gcog2 = cogimm2 - cogstd;
    gcog3 = cogimm3 - cogstd;
    
    label
        adjeduc='age adjusted education'
        gcog1='cogn score group-adjusted W1'
        gcog2='cogn score group-adjusted W2'
        gcog3='cogn score group-adjusted W3';
    drop lad0-lad3;
run;

proc univariate;
where clean and eligible and age7074=1;
var gcog1;
output out=pctile p10=gcogp10;
run;

proc print data=pctile;

data _null_;
    set pctile;
    if _n_=1 then call symput('pctile',gcogp10);
run;

data allwv;
    set allwv;    

    cogthr=&pctile+0;
    label cogthr='gcog1 threshold < 0.10 (age7074==1)';
    
    if proxyw1=0 then  cogim1 = (gcog1<cogthr);
    if proxyw1=1 then  cogim1 = cogn1;
    
    if proxyw2=0 then  cogim2 = (gcog2<cogthr);
    if proxyw2=1 then  cogim2 = cogn2;

    if proxyw3=0 then  cogim3 = (gcog3<cogthr);
    if proxyw3=1 then  cogim3 = cogn3;
    
    cogim2 = max(cogim2,cogim1);
    cogim3 = max(cogim3,cogim2,cogim1);
    
    label
        cogim1='cogn impairment prevalence W1'
        cogim2='cogn impairment prevalence W2'
        cogim3='cogn impairment prevalence W3';
    
run;

