/*****************************************************************/
/* FILE:        	common_demog.sas                         */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code demog vars common to all waves      */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

%macro code1(var);
   if &var.1 ne . then &var=&var.1;
   else do;
      if &var.2 ne . then &var=&var.2;
      else do;
	 if &var.3 ne . then &var=&var.3;
	 end;
      end;

   drop &var.1 &var.2 &var.3;   
%mend;

  
%macro code2(wv);   

   if married&wv ne . then single&wv = (married&wv=0);
   if single&wv  ne . then sf&wv     = (single&wv and female);
   if married&wv ne . then sm&wv     = (married&wv=0 and male);
   if married&wv ne . then mm&wv     = (married&wv=1 and male);   

   as70&wv = max(0,agem&wv-70*12);
   as80&wv = max(0,agem&wv-80*12);
   fas70&wv = as70&wv*female;
   fas80&wv = as80&wv*female;

   sas70&wv  = single&wv*as70&wv;
   msas70&wv = married&wv*as70&wv;
   sas80&wv  = single&wv*as80&wv;
   msas80&wv = married&wv*as80&wv;

   sfas70&wv = sas70&wv*female;
   smas70&wv = sas70&wv*male;
   mmas70&wv = msas70&wv*male;
   sfas80&wv = sas80&wv*female;
   smas80&wv = sas80&wv*male;
   mmas80&wv = msas80&wv*male;

   label
       single&wv="single w&wv"
       as70&wv="age spline max(0,age-70), w&wv"
       as80&wv="age spline max(0,age-80), w&wv"
       fas70&wv="female*max(0,age-70), w&wv"
       fas80&wv="female*max(0,age-80), w&wv"
       
      sf&wv     ="single female, w&wv"
      sfas70&wv ="sf*max(0,age-70), w&wv"
      sfas80&wv ="sf*max(0,age-80), w&wv"
      mm&wv     ="married male, w&wv"
      mmas70&wv ="mm*max(0,age-70), w&wv"
      mmas80&wv ="mm*max(0,age-80), w&wv"
      sm&wv     ="single male, w&wv"
      smas70&wv ="sm*max(0,age-70), w&wv"
      smas80&wv ="sm*max(0,age-80), w&wv"
      sas70&wv  ="single and as70, w&wv"
      sas80&wv  ="single and as80, w&wv"
      msas70&wv ="married and as70, w&wv"
      msas80&wv ="married and as80, w&wv";

%mend;


    
data allwv;
    set allwv;

    if birthyr=0 then birthyr=.;        
    
    male=(sex=1);
    female=(sex=2);

    %code1(hispan);
    %code1(nonwhit);
    %code1(black);
    %code1(raceo);
    %code1(usborn);
    %code1(colleg);
    %code1(hsgrad);
    %code1(dadhs);
    %code1(momhs);
    %code1(educ);
    %code1(magedie);
    %code1(pagedie);
    %code1(mageliv);
    %code1(pageliv);
    %code1(malive);
    %code1(palive);
    %code1(height);
    %code1(smokev);

    if nonwhit ne . and hispan ne . then white=(nonwhit=0 and hispan=0);
    if height=0 then height=.;

    if educ ne . then hs = (educ>10);
    if educ ne . then coll = (educ>14) ;
    finrsame=(dfinr=1 and bfinr=1);
    diffresp=((dfinr ne bfinr) or (proxyw1 ne proxyw2));

   label
       sex='sex'
       proxyw1='proxy interview, w1'
       proxyw2='proxy interview, w2'
       proxyw3='proxy interview, w3'
       race='race'
       black='black'
       raceo='other race'
       hispan='hispanic'
       white='white'
       nonwhit='non-white'
       usborn='born in US'
       weight='weight (pounds)'
       height='height (inches)'
       smokev = 'ever smoker'
       
       hsgrad='hs educ'
       colleg='colleg educ'
       grddeg='grad educ'
       educ='yrs education'
       momhs='mom hs educ'
       dadhs='dad hs educ'
       parnths='mom/dad hs educ'
       numkids='num kids ever'
       
       malive='mother alive'
       mageliv='age living mother'
       magedie='age mother died'
       palive='father alive'
       pageliv='age living father'
       pagedie='age father died'
       
       hs="educ > 10 yrs"
       coll="educ > 14 yrs"
       finrsame='same finr w1&w2'
       diffresp='diff resp w1&w2'
       ;
   
   %code2(1);
   %code2(2);
   %code2(3);
      
run;
