/*****************************************************************/
/* FILE:        	finaldata.sas                            */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Select analysis vars and working sample  */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%include "~/ribeiro/datagen/header.inc";
options ls=140;

proc freq data=local8.hwwdata;
    where clean and eligible;
tables
    married1*married2*married3*single2*spdied2*spdied3*tdied2*tdied3
    / missing list;


data hww123;
    set local8.hwwdata;
    if clean and eligible;

    lmonth12 = log(month12);
    lmonth23 = log(month23);

    if (married2=1)&(spdied2=1) then do;
       if widow2 ne . then widow2=1; 
       if married2 ne . then married2=0; 
       if single2 ne . then single2=1;
       end;
    if (married3=1)&(spdied3=1) then do;
       if widow3 ne . then widow3=1; 
       if married3 ne . then married3=0; 
       if single3 ne . then single3=1;
       end;
   
    if inw1=1 then status1=2;
    if inw1=0 then status1=1;
    if status1=. then status1=0;

    if inw2=1 then status2=2;
    if inw2=0 then do;
        if tdied2=1 and exitw2=0 then status2=3;
        if tdied2=1 and exitw2=1 then status2=4;
        end;
    if status2=. then status2=0;

    if inw3=1 then status3=2;
    if inw3=0 then do;
        if tdied3=1 and exitw3=0 then status3=3;
        if tdied3=1 and exitw3=1 then status3=4;
        end;
    if status3=. then status3=0;

    if (agem1>=840)&(agem1<=899)   then agegrp1=1; 
    if (agem1>=900)&(agem1<=959)   then agegrp1=2; 
    if (agem1>=960)&(agem1<=1019)  then agegrp1=3; 
    if (agem1>=1020)&(agem1<=1079) then agegrp1=4; 
    if (agem1>=1080)               then agegrp1=5; 

    if (agem2>=840)&(agem2<=899)   then agegrp2=1; 
    if (agem2>=900)&(agem2<=959)   then agegrp2=2; 
    if (agem2>=960)&(agem2<=1019)  then agegrp2=3; 
    if (agem2>=1020)&(agem2<=1079) then agegrp2=4; 
    if (agem2>=1080)               then agegrp2=5; 

    if (agem3>=840)&(agem3<=899)   then agegrp3=1; 
    if (agem3>=900)&(agem3<=959)   then agegrp3=2; 
    if (agem3>=960)&(agem3<=1019)  then agegrp3=3; 
    if (agem3>=1020)&(agem3<=1079) then agegrp3=4; 
    if (agem3>=1080)               then agegrp3=5; 

    if (married1=1)&(n2hhidw1=2)&(spdied2=0)&(married2=1)&(n2hhidw2=2) then sample2=1; 	
    if (married1=1)&(n2hhidw1=2)&(spdied2=1)&(married2=0)&(n2hhidw2=1) then sample2=2; 	
    if (married1=0)&(n2hhidw1=1)&(married2=0)&(n2hhidw2=1)             then sample2=3; 	
    if (married2=1)&(n2hhidw2=2)&(spdied3=0)&(married3=1)&(n2hhidw3=2) then sample3=1; 	
    if (married2=1)&(n2hhidw2=2)&(spdied3=1)&(married3=0)&(n2hhidw3=1) then sample3=2; 	
    if (married2=0)&(n2hhidw2=1)&(married3=0)&(n2hhidw3=1)             then sample3=3; 	

    if hoodfr1 ne . and hoodpr1 ne . then hoodpf1=((hoodfr1=1) or (hoodpr1=1)); 
    if condfr1 ne . and condpr1 ne . then condpf1=((condfr1=1) or (condpr1=1)); 
    
    if hoodfr2 ne . and hoodpr2 ne . then hoodpf2=((hoodfr2=1) or (hoodpr2=1)); 
    if condfr2 ne . and condpr2 ne . then condpf2=((condfr2=1) or (condpr2=1)); 
    
    if hoodfr3 ne . and hoodpr3 ne . then hoodpf3=((hoodfr3=1) or (hoodpr3=1)); 
    if condfr3 ne . and condpr3 ne . then condpf3=((condfr3=1) or (condpr3=1)); 

    q1wc1 = (q_2wc1=1);
    q1wc2 = (q_2wc2=1);
    q1wc3 = (q_2wc3=1);

    q4wc1 = (q_2wc1=4);
    q4wc2 = (q_2wc2=4);
    q4wc3 = (q_2wc3=4);

    q1ic1 = (q_2ic1=1);
    q1ic2 = (q_2ic2=1);

    q4ic1 = (q_2ic1=4);
    q4ic2 = (q_2ic2=4);

    q1wb1 = (q_2wb1=1);
    q1wb2 = (q_2wb2=1);
    q1wb3 = (q_2wb3=1);

    q4wb1 = (q_2wb1=4);
    q4wb2 = (q_2wb2=4);
    q4wb3 = (q_2wb3=4);

    q1ib1 = (q_2ib1=1);
    q1ib2 = (q_2ib2=1);

    q4ib1 = (q_2ib1=4);
    q4ib2 = (q_2ib2=4);

label
    status1='0=NA,1=attr,2=inw,3=died/noexit,4=died/exit, w1'
    status2='0=NA,1=attr,2=inw,3=died/noexit,4=died/exit, w2'
    status3='0=NA,1=attr,2=inw,3=died/noexit,4=died/exit, w3'
    
    sample2='1=couple-couple,2=couple-single,3=single-single, w2'
    sample3='1=couple-couple,2=couple-single,3=single-single, w3'

    agegrp1='Age categ - 1=70-75, 2=75-80 ..., w1'
    agegrp2='Age categ - 1=70-75, 2=75-80 ..., w2'
    agegrp3='Age categ - 1=70-75, 2=75-80 ..., w3'

    hoodpf1='neighborhood fair/poor w1'
    hoodpf2='neighborhood fair/poor w2'
    hoodpf3='neighborhood fair/poor w3'
    
    condpf1='house condition fair/poor w1'
    condpf2='house condition fair/poor w2'
    condpf3='house condition fair/poor w3'
    
    q1wc1='low wlth. quart. (per cap), w1'
    q1wc2='low wlth. quart. (per cap), w2'
    q1wc3='low wlth. quart. (per cap), w3'

    q4wc1='high wlth. quart. (per cap), w1'
    q4wc2='high wlth. quart. (per cap), w2'
    q4wc3='high wlth. quart. (per cap), w3'

    q1ic1='low inc. quart. (per cap), w1'
    q1ic2='low inc. quart. (per cap), w2'

    q4ic1='high inc. quart. (per cap), w1'
    q4ic2='high inc. quart. (per cap), w2'

    q1wb1='low wlth. quart. (mar stat), w1'
    q1wb2='low wlth. quart. (mar stat), w2'
    q1wb3='low wlth. quart. (mar stat), w3'

    q4wb1='high wlth. quart. (mar stat), w1'
    q4wb2='high wlth. quart. (mar stat), w2'
    q4wb3='high wlth. quart. (mar stat), w3'

    q1ib1='low inc. quart. (mar stat), w1'
    q1ib2='low inc. quart. (mar stat), w2'

    q4ib1='high inc. quart. (mar stat), w1'
    q4ib2='high inc. quart. (mar stat), w2'
    ;
run;

%count(hww123,hhid,nhh);
proc sort data=hww123; by hhid agegrp1; run;
data hww123;
    set hww123;
    by hhid agegrp1;
    hhlevel=(first.hhid=1);
    label
        nhh='num of hh members in sample' 
        hhlevel='subset to hh-level sample';
run;

proc freq;
    where clean and eligible;
tables
    married1*married2*married3*single2*spdied2*spdied3*tdied2*tdied3
    status1*status2*status3*inw1*inw2*inw3*tdied2*tdied3*exitw2*exitw3

    / missing list;


proc means ;
    var months1-months3 month12 month23 monthd2 monthd3;
proc means p25 p50 p75;
    var c_2w1 c_2i1;
    output out=tmp(keep=qw25 qi25 medw medi qw75 qi75)
        p25=qw25 qi25 p50=medw medi p75=qw75 qi75;
run;
proc print data=tmp;

data hww123;
    set hww123;
    pnt=1;
    set tmp point=pnt;

    iqrw=qw75-qw25;
    wlth1n=(c_2w1-medw)/iqrw;
    wlth2n=(c_2w2-medw)/iqrw;
    wlth3n=(c_2w3-medw)/iqrw;
    
    wlth1=1/(1+exp(-wlth1n));
    wlth2=1/(1+exp(-wlth2n));
    wlth3=1/(1+exp(-wlth3n));
    
    cwlth2=wlth2-wlth1-ret12bd*wlth1*(1-wlth1)*wlth1n;
    cwlth3=wlth3-wlth2-ret23bd*wlth2*(1-wlth2)*wlth2n;
    
    iqri=qi75-qi25;
    inc1n=(c_2i1-medi)/iqri;
    inc2n=(c_2i2-medi)/iqri;
    
    inc1=1/(1+exp(-inc1n));
    inc2=1/(1+exp(-inc2n));
    
    cinc2=inc2-inc1;

    
label
    wlth1n='normalized wealth, w1'    
    wlth2n='normalized wealth, w2'    
    wlth3n='normalized wealth, w3'    

    wlth1='logistic transformation of wealth, w1'    
    wlth2='logistic transformation of wealth, w2'    
    wlth3='logistic transformation of wealth, w3'    
    cwlth2='change in trnsfmd. wealth, w2' 
    cwlth3='change in trnsfmd. wealth, w3' 

    inc1n='normalized income, w1'    
    inc2n='normalized income, w2'    

    inc1='logistic transformation of income, w1'    
    inc2='logistic transformation of income, w2'    
    cinc2='change in trnsfmd. income, w2' 
    ;
    drop pnt qw25 qi25 medw medi qw75 qi75 iqrw iqri;
    
run;

proc means ;
    var
        wlth1n wlth2n  wlth3n
        wlth1  wlth2   wlth3
        cwlth2 cwlth3 
        inc1n  inc2n  
        inc1   inc2   
        cinc2             
        dnhous1-dnhous3
        mobhome1-mobhome3
        ;
run;


    %let hww123=
        hhidpn hhid eligible clean spdied2 spdied3
        dsubhh fsubhh nhh hhlevel
        inw1 inw2 inw3 exitw2 exitw3 tdied2 tdied3
        status1-status3
        sample2-sample3
        agedie2 agedie3
        agem1 agem2 agem3
        sagem1 sagem2 sagem3
        agegrp1-agegrp3
        month12 month23 monthd2 monthd3 months1 months2 months3
        r_m1 r_m2 r_m3 r_m12 r_m23 r_md2 r_md3
        lmonth12 lmonth23
        smonth12 smonth23
        race1 race2
        moved2 moved3
        
        male 
        
        age    sex  female  hispan  nonwhit   black   raceo   white  usborn 
        sage s_sex sfemale  shispan snonwhit s_black s_raceo s_white s_usbrn 
    
        educ    adjeduc   coll   hs   dadhs   momhs magedie1 pagedie1 
        s_educ sadjeduc s_coll s_hs s_dadhs s_momhs smagedi1 spagedi1 
        
        n2hhidw1 n2hhidw2 n2hhidw3

         as701  as702  as703
        fas701 fas702 fas703
         as801  as802  as803
        fas801 fas802 fas803
        
         spas701  spas702  spas703
        spfas701 spfas702 spfas703
         spas801  spas802  spas803
        spfas801 spfas802 spfas803
        
        married1 single1 widow1 divsep1 nevmarr1 
        married2 single2 widow2 divsep2 nevmarr2 
        married3 single3 widow3 divsep3 nevmarr3 

        swidow1   sdivsep1 snevmar1  
        swidow2   sdivsep2 snevmar2  
        swidow3   sdivsep3 snevmar3  

        finrsame diffresp
        
        sf1 sm1 mm1 sas701 msas701 sas801 msas801 sfas701 smas701 mmas701 sfas801 smas801 mmas801 
        sf2 sm2 mm2 sas702 msas702 sas802 msas802 sfas702 smas702 mmas702 sfas802 smas802 mmas802 
        sf3 sm3 mm3 sas703 msas703 sas803 msas803 sfas703 smas703 mmas703 sfas803 smas803 mmas803 

        duplex1 mobhome1 othhous1 aptment1 singfam1
        duplex2 mobhome2 othhous2 aptment2 singfam2
        duplex3 mobhome3 othhous3 aptment3 singfam3

        condex1 condfr1 condgd1 condpr1 condvg1 
        condex2 condfr2 condgd2 condpr2 condvg2 
        condex3 condfr3 condgd3 condpr3 condvg3 

        hoodex1 hoodfr1 hoodgd1 hoodpr1 hoodvg1
        hoodex2 hoodfr2 hoodgd2 hoodpr2 hoodvg2
        hoodex3 hoodfr3 hoodgd3 hoodpr3 hoodvg3

        hoodpf1 condpf1
        hoodpf2 condpf2
        hoodpf3 condpf3

        hlthbet1 hlthsam1 hlthwrs1 hlthex1 hlthfr1 hlthgd1 hlthpr1 hlthvg1
        hlthbet2 hlthsam2 hlthwrs2 hlthex2 hlthfr2 hlthgd2 hlthpr2 hlthvg2
        hlthbet3 hlthsam3 hlthwrs3 hlthex3 hlthfr3 hlthgd3 hlthpr3 hlthvg3
                        
        s_h_bet1 s_h_sam1 s_h_wrs1 s_hthex1 s_hthfr1 s_hthgd1 s_hthpr1 s_hthvg1
        s_h_bet2 s_h_sam2 s_h_wrs2 s_hthex2 s_hthfr2 s_hthgd2 s_hthpr2 s_hthvg2
        s_h_bet3 s_h_sam3 s_h_wrs3 s_hthex3 s_hthfr3 s_hthgd3 s_hthpr3 s_hthvg3


        h_exvg1  h_frpr1
        h_exvg2  h_frpr2
        h_exvg3  h_frpr3
                        
        sh_exvg1 sh_frpr1
        sh_exvg2 sh_frpr2
        sh_exvg3 sh_frpr3
        
        smokev
        ssmokev
        
        cogimm1 pcog1_1 pcog1_1 cogn1 gcog1 cogprxy1 
        cogimm2 pcog1_2 pcog1_2 cogn2 gcog2 cogprxy2 
        cogimm3 pcog1_3 pcog1_3 cogn3 gcog3 cogprxy3 
                                               
        cesd8_1 hlth1 numdrnk1                 
        cesd8_2 hlth2 numdrnk2                 
        cesd8_3 hlth3 numdrnk3                 
        
        cancer1   heart1  stroke1  lung1  diabet1  highbp1  arthrt1  incont1  fall1  hipfrc1 proxyw1 cogim1 psych1 depres1 
        cancer2   heart2  stroke2  lung2  diabet2  highbp2  arthrt2  incont2  fall2  hipfrc2 proxyw2 cogim2 psych2 depres2 
        cancer3   heart3  stroke3  lung3  diabet3  highbp3  arthrt3  incont3  fall3  hipfrc3 proxyw3 cogim3 psych3 depres3 
        
        scancer1 sheart1 sstroke1 slung1 sdiabet1 shighbp1 sarthrt1 sincont1 sfall1 shipfrc1 sproxyw1 scogim1 spsych1 sdepres1 
        scancer2 sheart2 sstroke2 slung2 sdiabet2 shighbp2 sarthrt2 sincont2 sfall2 shipfrc2 sproxyw2 scogim2 spsych2 sdepres2 
        scancer3 sheart3 sstroke3 slung3 sdiabet3 shighbp3 sarthrt3 sincont3 sfall3 shipfrc3 sproxyw3 scogim3 spsych3 sdepres3 
        
        lobmi1   hibmi1  bmilow1  bmihi1 bmi1
        lobmi2   hibmi2  bmilow2  bmihi2 bmi2        
        lobmi3   hibmi3  bmilow3  bmihi3 bmi3
        
        slobmi1 shibmi1 sbmilow1 sbmihi1 sbmi1
        slobmi2 shibmi2 sbmilow2 sbmihi2 sbmi2
        slobmi3 shibmi3 sbmilow3 sbmihi3 sbmi3
        
        
        smoknow1 numadl1  numiadl1  dadl1  diadl1   adl1_21 adlgt31  iadl1_21 iadlgt31  
        smoknow2 numadl2  numiadl2  dadl2  diadl2   adl1_22 adlgt32  iadl1_22 iadlgt32 
        smoknow3 numadl3  numiadl3  dadl3  diadl3   adl1_23 adlgt33  iadl1_23 iadlgt33 
                                                  
        ssmoknw1 snumadl1 snmiadl1 sdadl1 sdiadl1  sadl1_21 sadlgt31 siadl121 siadlg31 
        ssmoknw2 snumadl2 snmiadl2 sdadl2 sdiadl2  sadl1_22 sadlgt32 siadl122 siadlg32 
        ssmoknw3 snumadl3 snmiadl3 sdadl3 sdiadl3  sadl1_23 sadlgt33 siadl123 siadlg33 

        dhlth1 drnknow1
        dhlth2 drnknow2
        dhlth3 drnknow3
               
        sdhlth1 sdrnknw1
        sdhlth2 sdrnknw2        
        sdhlth3 sdrnknw3


        
        bmibt2   bmiws2  bmibt3  bmiws3
        sbmibt2 sbmiws2 sbmibt3 sbmiws3
        
        ihighbp2 ilung2 iarthrt2 idiabet2 icancer2 iheart2 istroke2 ipsych2 ifall2 ihipfrc2 iincont2 idepres2 
        ihighbp3 ilung3 iarthrt3 idiabet3 icancer3 iheart3 istroke3 ipsych3 ifall3 ihipfrc3 iincont3 idepres3 

        sihghbp2 silung2 siartht2 sidiabt2 sicancr2 siheart2 sistrok2 sipsych2 sifall2 sihipfr2 siincot2 sideprs2
        sihghbp3 silung3 siartht3 sidiabt3 sicancr3 siheart3 sistrok3 sipsych3 sifall3 sihipfr3 siincot3 sideprs3
        
        idadl2 idiadl2 idhlth2  icogim2 
        idadl3 idiadl3 idhlth3  icogim3

        sidadl2 sidiadl2 sicogim2 sidhlth2 
        sidadl3 sidiadl3 sicogim3 sidhlth3 

        ncancer2 nheart2 nstroke2 
        jcancer2 jheart2 jstroke2 jfall2 jincont2 jhipfrc2
        sjcancr2 sjheart2 sjstrok2 sjfall2 sjincot2 sjhipfr2
        
        ncancer3 nheart3 nstroke3 
        jcancer3 jheart3 jstroke3  jfall3 jincont3 jhipfrc3
        sjcancr3 sjheart3 sjstrok3 sjfall3 sjincot3 sjhipfr3
        mcancer3 ycancer3 dycancr3
        
        q1wc1 q_2wc1
        q1wc2 q_2wc2
        q1wc3 q_2wc3
        
        q4wc1 
        q4wc2 
        q4wc3 
        
        q1ic1 q_2ic1
        q1ic2 q_2ic2
        
        q4ic1 
        q4ic2 
        
        q1wb1 q_2wb1 q_2lb1 q_2nb1
        q1wb2 q_2wb2 q_2lb2 q_2nb2
        q1wb3 q_2wb3 q_2lb3 q_2nb3
        
        q4wb1 
        q4wb2 
        q4wb3 
        
        q1ib1 q_2ib1
        q1ib2 q_2ib2
        
        q4ib1 
        q4ib2 

        
        wlth1n wlth1 c_2w1 c_2l1 c_2n1 
        wlth2n wlth2 c_2w2 c_2l2 c_2n2
        wlth3n wlth3 c_2w3 c_2l3 c_2n3
        ret12bd
        ret23bd        
        cwlth2
        cwlth3
        inc1n inc1 c_2i1
        inc2n inc2 c_2i2

        dnhous1-dnhous3

            ;

/* ----------------------------------------------------------------
 * ----------------------------------------------------------------
 * ----------------------------------------------------------------
 * ----------------------------------------------------------------
 */


data local8.hww123;
    set hww123;
    keep &hww123;
run;


proc means;
proc printto  print="&base/PSID/newahead/hww/means123.asc" new; run;
proc means;
proc printto print=print; run;










