/*****************************************************************/
/* FILE:        	impcat1.sas                              */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Categorical asset imputation wave 1      */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

data w1assets;
set local8.w1assets;
run;

%merge(w1assets,w1assets,wv1,hhid,1);

    
%let seed=1;
%let cntrlv=nhhbppn;
%let impv =c_hous1 c_stck1 c_chck1 c_rlst1;
%let impvn=cnhous1 cnstck1 cnchck1 cnrlst1;
%let mapd=asstcat.c_hous1 asstcat.c_stck1 asstcat.c_chck1 asstcat.c_rlst1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);


%let cntrlv=nhhbppn cnhous1 cnstck1 cnchck1 cnrlst1;

%let seed=2;
%let impv =c_trns1;
%let impvn=cntrns1;
%let mapd=asstcat.c_trns1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=3;
%let impv =c_ira1;
%let impvn=cnira1;
%let mapd=asstcat.c_ira1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=4;
%let impv =c_bsns1;
%let impvn=cnbsns1;
%let mapd=asstcat.c_bsns1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=5;
%let impv =c_cd1;
%let impvn=cncd1;
%let mapd=asstcat.c_cd1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=6;
%let impv =c_bond1;
%let impvn=cnbond1;
%let mapd=asstcat.c_bond1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=7;
%let impv =c_othr1;
%let impvn=cnothr1;
%let mapd=asstcat.c_othr1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=8;
%let impv =c_debt1;
%let impvn=cndebt1;
%let mapd=asstcat.c_debt1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=9;
%let cntrlv=nhhbppn cnhous1 cnchck1 cnrlst1;
%let impv =c_mobh1 c_mort1 c_2mrt1 c_loan1;
%let impvn=cnmobh1 cnmort1 cn2mrt1 cnloan1;
%let mapd=asstcat.c_mobh1 asstcat.c_mort1 asstcat.c_2mrt1 asstcat.c_loan1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);

%let seed=10;
%let cntrlv=nhhbppn cnhous1 cnstck1 cnchck1 cnrlst1;
%let impv =c_tinc1;
%let impvn=cntinc1;
%let mapd=asstcat.c_tinc1;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);


data map1;
    input v1 v2 v3 v4 v5 hcond1;
    cards;
        1 0 0 0 0 1
        0 1 0 0 0 2
        0 0 1 0 0 3
        0 0 0 1 0 4
        0 0 0 0 1 5
        1 1 1 1 1 6
            ;
run;

data map2;
    input v1 v2 v3 v4 v5 nhood1;
    cards;
        1 0 0 0 0 1
        0 1 0 0 0 2
        0 0 1 0 0 3
        0 0 0 1 0 4
        0 0 0 0 1 5
        1 1 1 1 1 6
            ;
run;

data w1assets;
    set w1assets;
    if hcond1 in(.,.R,.D) then hcond1=6;
    if nhood1 in(.,.R,.D) then nhood1=6;
run;

%let seed=11;
%let cntrlv=nhhbppn cnhous1 cnmobh1 cnrlst1;
%let impv  =hcond1  nhood1;
%let impvn=nhcond1 nnhood1;
%let mapd=map1 map2;
%impcat(w1assets,&impv,&impvn,&mapd,&cntrlv,&seed);
    
%let cvars=%list2_4(cn,1,2);;
%let dvars=%list2_4(dn,1,2);;
      
data local8.w1astc;
    set w1assets;
    array cn{*} &cvars;
    array dn{*} &dvars;
    do i=1 to dim(cn);
        dn{i}=(cn{i}>0);
        end;
    drop i;

    nhood1=nnhood1;
    hcond1=nhcond1;
    drop nnhood1 nhcond1;

    hoodex1=(nhood1=1);
    hoodvg1=(nhood1=2);
    hoodgd1=(nhood1=3);
    hoodfr1=(nhood1=4);
    hoodpr1=(nhood1=5);

    condex1=(hcond1=1);
    condvg1=(hcond1=2);
    condgd1=(hcond1=3);
    condfr1=(hcond1=4);
    condpr1=(hcond1=5);
    
    %labeli(cn,rlst,w1);
    %labeli(cn,bsns,w1);
    %labeli(cn,ira,w1);
   *%labeli(cn,ira1,w1);
   *%labeli(cn,ira2,w1);
   *%labeli(cn,ira3,w1);
    %labeli(cn,stck,w1);
    %labeli(cn,bond,w1);
    %labeli(cn,chck,w1);
    %labeli(cn,cd,w1);
    %labeli(cn,othr,w1);
    %labeli(cn,trns,w1);
    %labeli(cn,debt,w1);
    %labeli(cn,mobh,w1);
    %labeli(cn,hous,w1);
    %labeli(cn,mort,w1);
    %labeli(cn,2mrt,w1);
    %labeli(cn,loan,w1);
    %labeli(cn,tinc,w1);

    
run;
proc means; var &dvars; run;

